@@ -257,10 +257,28 @@ sub formatTable($)
 #-------------------------------------------------------------------------------
 
 sub indentString($$)
- {my ($string, $indent) = @_;                                                   # The string iof lines to indent, the indenting string
+ {my ($string, $indent) = @_;                                                   # The string of lines to indent, the indenting string
   join "\n", map {$indent.$_} split "\n", $string
  }
 
+#-------------------------------------------------------------------------------
+# Load a hash: first word of each line is the key and the rest is the value
+#-------------------------------------------------------------------------------
+
+sub loadHashFromLines($)
+ {my ($string) = @_;                                                            # The string of lines from which to create a hash
+  +{map{split /\s+/, $_, 2} split "\n", $string}
+ }
+
+#-------------------------------------------------------------------------------
+# Normalize white space
+#-------------------------------------------------------------------------------
+
+sub normalizeWhiteSpace($)
+ {my ($string) = @_;                                                            # The string in which to normalize the whitespace
+  $string =~ s/\s+/ /gr =~ s/\A\s+//r =~ s/\s+\Z//r
+ }
+
 #-------------------------------------------------------------------------------
 # Check the keys in a hash
 #-------------------------------------------------------------------------------
@@ -312,10 +330,12 @@ use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION);
 
 @ISA          = qw(Exporter);
 @EXPORT       = qw(formatTable);
-@EXPORT_OK    = qw(dateStamp dateTimeStamp fileList fileSize makePath readBinaryFile readFile timeStamp writeBinaryFile writeFile);
+@EXPORT_OK    = qw(checkKeys dateStamp dateTimeStamp fileList fileSize
+indentString loadHashFromLines makePath normalizeWhiteSpace
+readBinaryFile readFile timeStamp writeBinaryFile writeFile);
 %EXPORT_TAGS  = (all=>[@EXPORT_OK]);
 
-$VERSION = '1.002'; # Wednesday 14 December 2016
+$VERSION = '1.003'; # Wednesday 14 December 2016
 
 1;
 
@@ -421,7 +441,7 @@ modified under the same terms as Perl itself.
 =cut
 
 __DATA__
-use Test::More tests => 20;
+use Test::More tests => 21;
 if (1)                                                                          # Unicode
  {use utf8;
   my $z = "𝝰𝝱𝝲";
@@ -480,8 +500,10 @@ if (1)
  }
 
 if (1)                                                                          # H
- {my $s = checkKeys({qw(go 1 Went 2 gone 3)}, {qw(go present went past gone presentPast)});
-  my $S = <<END;
+ {my $s = normalizeWhiteSpace
+    checkKeys({qw(go 1 Went 2 gone 3)},
+              {qw(go present went past gone presentPast)});
+  my $S = normalizeWhiteSpace <<END;
 Invalid options chosen:
   Went
 Permitted options are:
@@ -489,7 +511,13 @@ Permitted options are:
   gone  presentPast
   went  past
 END
-  $s =~ s/\s+/ /g;
-  $S =~ s/\s+/ /g;
   ok $s eq $S;
  }
+
+if (1)                                                                          # H
+ {my $s = loadHashFromLines <<END;
+a 10 11 12
+b 20 21 22
+END
+  ok dump($s) eq '{ a => "10 11 12", b => "20 21 22" }';
+ }
